.. _cite: Citation ======== .. [1] Ameli, S., and Shadden. S. C. (2022). *Interpolating Log-Determinant and Trace of the Powers of Matrix* :math:`\mathbf{A} + t \mathbf{B}`. Statistics and Computing 32, 108. |btn-int-doi| |ameli-int-arxiv| |btn-bib-int| |btn-view-pdf-int| .. raw:: html

            @article{Ameli2022,
                title    = {Interpolating log-determinant and trace of the powers of matrix \(\mathbf{A} + t \mathbf{B}\)},
                author   = {Ameli, Siavash and Shadden, Shawn C.},
                journal  = {Statistics and Computing},
                volume   = {32},
                number   = {6},
                pages    = {108},
                month    = {Nov},
                year     = {2022},
                doi      = {10.1007/s11222-022-10173-4},
                url      = {https://doi.org/10.1007/s11222-022-10173-4},
            }
.. [2] Ameli, S. (2022). ameli/ortho: (v0.2.0). Zenodo. |ortho-zenodo| |btn-bib-ortho| .. raw:: html

            @misc{zenodo.308965310,
                title = {ameli/ortho: (v0.2.0)},
                author = {Ameli, S.},
                year = {2022},
                howpublished = {\url{https://pypi.org/project/ortho/}}
            }
.. |btn-bib-int| raw:: html
.. |btn-bib-ortho| raw:: html
.. |btn-view-pdf-int| raw:: html
.. |btn-int-doi| raw:: html DOI .. |ameli-int-arxiv| image:: https://img.shields.io/badge/arXiv-2009.07385-b31b1b.svg :target: https://doi.org/10.48550/arXiv.2009.07385 :alt: arXiv 2009.07385 .. |ortho-zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.6395268.svg :target: https://doi.org/10.5281/zenodo.6395268 :alt: doi: 10.5281/zenodo.6395268